@@ -316,6 +316,7 @@ class PlotlyMixin:
             "box",
             "lasso",
         ),
+        config: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> DeltaGenerator | PlotlyState:
         """Display an interactive Plotly chart.
@@ -415,6 +416,12 @@ class PlotlyMixin:
 
             All selections modes are activated by default.
 
+        config : dict or None
+            A dictionary of Plotly configuration options. This is passed to
+            Plotly's ``show()`` function. For more information about Plotly
+            configuration options, see Plotly's documentation on `Configuration
+            in Python <https://plotly.com/python/configuration-options/>`_.
+
         **kwargs
             Additional arguments accepted by Plotly's ``plot()`` function.
 
@@ -423,6 +430,10 @@ class PlotlyMixin:
             see Plotly's documentation on `Configuration in Python
             <https://plotly.com/python/configuration-options/>`_.
 
+            .. deprecated::
+               ``**kwargs`` are deprecated and will be removed in a future
+               release. Use ``config`` instead.
+
         Returns
         -------
         element or dict
@@ -493,11 +504,11 @@ class PlotlyMixin:
         # for their main parameter. I don't like the name, but it's best to
         # keep it in sync with what Plotly calls it.
 
-        if "sharing" in kwargs:
+        if kwargs:
             show_deprecation_warning(
-                "The `sharing` parameter has been deprecated and will be removed "
-                "in a future release. Plotly charts will always be rendered using "
-                "Streamlit's offline mode."
+                "The keyword arguments have been deprecated and will be removed "
+                "in a future release. Use `config` instead to specify Plotly "
+                "configuration options."
             )
 
         if theme not in ["streamlit", None]:
@@ -542,11 +553,7 @@ class PlotlyMixin:
         plotly_chart_proto.theme = theme or ""
         plotly_chart_proto.form_id = current_form_id(self.dg)
 
-        config = dict(kwargs.get("config", {}))
-        # Copy over some kwargs to config dict. Plotly does the same in plot().
-        config.setdefault("showLink", kwargs.get("show_link", False))
-        config.setdefault("linkText", kwargs.get("link_text", False))
-
+        config = config or {}
         plotly_chart_proto.spec = plotly.io.to_json(figure, validate=False)
         plotly_chart_proto.config = json.dumps(config)
 
@@ -558,6 +565,7 @@ class PlotlyMixin:
         plotly_chart_proto.id = compute_and_register_element_id(
             "plotly_chart",
             user_key=key,
+            key_as_main_identity=False,
             dg=self.dg,
             plotly_spec=plotly_chart_proto.spec,
             plotly_config=plotly_chart_proto.config,
